@@ -4,7 +4,7 @@ var g_AttackTypes = ["Melee", "Ranged", "Capture"];
 
 Attack.prototype.preferredClassesSchema =
 	"<optional>" +
-		"<element name='PreferredClasses' a:help='Space delimited list of classes preferred for attacking. If an entity has any of theses classes, it is preferred. The classes are in decending order of preference'>" +
+		"<element name='PreferredClasses' a:help='Space delimited list of classes preferred for attacking. If an entity has any of theses classes, it is preferred. The classes are in descending order of preference'>" +
 			"<attribute name='datatype'>" +
 				"<value>tokens</value>" +
 			"</attribute>" +
@@ -270,6 +270,7 @@ Attack.prototype.CanAttack = function(target, wantedTypes)
 	const entityOwner = cmpEntityPlayer.GetPlayerID();
 	const targetOwner = cmpTargetPlayer.GetPlayerID();
 	const cmpCapturable = QueryMiragedInterface(target, IID_Capturable);
+	const cmpDiplomacy = QueryPlayerIDInterface(entityOwner, IID_Diplomacy);
 
 	// Check if the relative height difference is larger than the attack range
 	// If the relative height is bigger, it means they will never be able to
@@ -278,7 +279,7 @@ Attack.prototype.CanAttack = function(target, wantedTypes)
 
 	for (const type of types)
 	{
-		if (type != "Capture" && (!cmpEntityPlayer.IsEnemy(targetOwner) || !cmpHealth || !cmpHealth.GetHitpoints()))
+		if (type != "Capture" && (!cmpDiplomacy?.IsEnemy(targetOwner) || !cmpHealth || !cmpHealth.GetHitpoints()))
 			continue;
 
 		if (type == "Capture" && (!cmpCapturable || !cmpCapturable.CanCapture(entityOwner)))
@@ -345,6 +346,8 @@ Attack.prototype.GetFullAttackRange = function()
 Attack.prototype.GetAttackEffectsData = function(type, splash)
 {
 	let template = this.template[type];
+	if (!template)
+		return undefined;
 	if (splash)
 		template = template.Splash;
 	return AttackHelper.GetAttackEffectsData("Attack/" + type + (splash ? "/Splash" : ""), template, this.entity);
@@ -358,15 +361,12 @@ Attack.prototype.GetAttackEffectsData = function(type, splash)
  */
 Attack.prototype.GetBestAttackAgainst = function(target, allowCapture)
 {
-	let cmpFormation = Engine.QueryInterface(target, IID_Formation);
-	if (cmpFormation)
-	{
+	let types = this.GetAttackTypes();
+	if (Engine.QueryInterface(target, IID_Formation))
 		// TODO: Formation against formation needs review
-		let types = this.GetAttackTypes();
 		return g_AttackTypes.find(attack => types.indexOf(attack) != -1);
-	}
 
-	let cmpIdentity = Engine.QueryInterface(target, IID_Identity);
+	const cmpIdentity = Engine.QueryInterface(target, IID_Identity);
 	if (!cmpIdentity)
 		return undefined;
 
@@ -374,23 +374,22 @@ Attack.prototype.GetBestAttackAgainst = function(target, allowCapture)
 	if (this.template.Slaughter && cmpIdentity.HasClass("Domestic"))
 		return "Slaughter";
 
-	let types = this.GetAttackTypes().filter(type => this.CanAttack(target, [type]));
+	const targetClasses = cmpIdentity.GetClassesList();
+	const getPreferrence = attackType => {
+		let pref = 0;
+		if (MatchesClassList(targetClasses, this.GetPreferredClasses(attackType)))
+			pref += 2;
+		if (allowCapture ? attackType === "Capture" : attackType !== "Capture")
+			pref++;
+		return pref;
+	};
 
-	// Check whether the target is capturable and prefer that when it is allowed.
-	let captureIndex = types.indexOf("Capture");
-	if (captureIndex != -1)
-	{
-		if (allowCapture)
-			return "Capture";
-		types.splice(captureIndex, 1);
-	}
-
-	let targetClasses = cmpIdentity.GetClassesList();
-	let isPreferred = attackType => MatchesClassList(targetClasses, this.GetPreferredClasses(attackType));
-
-	return types.sort((a, b) =>
-		(types.indexOf(a) + (isPreferred(a) ? types.length : 0)) -
-		(types.indexOf(b) + (isPreferred(b) ? types.length : 0))).pop();
+	return types.filter(type => this.CanAttack(target, [type])).sort((a, b) => {
+		const prefA = getPreferrence(a);
+		const prefB = getPreferrence(b);
+		return (types.indexOf(a) + (prefA > 0 ? prefA + types.length : 0)) -
+			(types.indexOf(b) + (prefB > 0 ? prefB + types.length : 0))
+	}).pop();
 };
 
 Attack.prototype.CompareEntitiesByPreference = function(a, b)
@@ -464,6 +463,11 @@ Attack.prototype.GetAttackYOrigin = function(type)
 	return ApplyValueModificationsToEntity("Attack/" + type + "/Origin/Y", +this.template[type].Origin.Y, this.entity);
 };
 
+Attack.prototype.RepeatRangeCheck = function (type) {
+	if (!this.IsTargetInRange(this.target, type))
+		this.StopAttacking("OutOfRange");
+};
+
 /**
  * @param {number} target - The target to attack.
  * @param {string} type - The type of attack to use.
@@ -503,12 +507,26 @@ Attack.prototype.StartAttacking = function(target, type, callerIID)
 		cmpVisual.SetAnimationSyncOffset(prepare);
 	}
 
+	// Find the number of range checks needed during repeat time.
+	const numCheck = Math.ceil(timings.repeat / 1000);
+
+	// Calculate the timing offset to be half the check repeat time.
+	const repeatPerCheck = timings.repeat / numCheck;
+	const offset = repeatPerCheck / 2;
+
+	// Set the startpoint to be the prepare time plus any remaining time not evenly divisible by the offset.
+	let checkStart = timings.prepare + ((prepare - timings.prepare) % offset);
+
+	// Add an offset to the start time if we are not already offset.
+	if ((prepare - checkStart) % repeatPerCheck === 0)
+		checkStart += offset;
+
 	// If using a non-default prepare time, re-sync the animation when the timer runs.
 	this.resyncAnimation = prepare != timings.prepare;
 	this.target = target;
 	this.callerIID = callerIID;
 	this.timer = cmpTimer.SetInterval(this.entity, IID_Attack, "Attack", prepare, timings.repeat, type);
-
+	this.checkTimer = cmpTimer.SetInterval(this.entity, IID_Attack, "RepeatRangeCheck", checkStart, repeatPerCheck, type);
 	return true;
 };
 
@@ -522,7 +540,9 @@ Attack.prototype.StopAttacking = function(reason)
 
 	let cmpTimer = Engine.QueryInterface(SYSTEM_ENTITY, IID_Timer);
 	cmpTimer.CancelTimer(this.timer);
+	cmpTimer.CancelTimer(this.checkTimer);
 	delete this.timer;
+	delete this.checkTimer;
 
 	const cmpResistance = QueryMiragedInterface(this.target, IID_Resistance);
 	if (cmpResistance)
@@ -675,7 +695,7 @@ Attack.prototype.PerformAttack = function(type, target)
 		let predictedHeight = cmpTargetPosition.GetHeightAt(predictedPosition.x, predictedPosition.z);
 
 		// Add inaccuracy based on spread.
-		let distanceModifiedSpread = ApplyValueModificationsToEntity("Attack/" + type + "/Spread", +this.template[type].Projectile.Spread, this.entity) *
+		const distanceModifiedSpread = ApplyValueModificationsToEntity("Attack/" + type + "/Projectile/Spread", +this.template[type].Projectile.Spread, this.entity) *
 			predictedPosition.horizDistanceTo(selfPosition) / 100;
 
 		let randNorm = randomNormal2D();
