@@ -145,19 +145,15 @@ Trainer.prototype.Item.prototype.Stop = function()
 			cmpPlayerEntityLimits.ChangeMatchCount(this.templateName, -this.count);
 	}
 
-	const cmpStatisticsTracker = QueryPlayerIDInterface(this.player, IID_StatisticsTracker);
-	const totalCosts = {};
-	for (const resource in this.resources)
-	{
-		totalCosts[resource] = Math.floor(this.count * this.resources[resource]);
-		if (cmpStatisticsTracker)
-			cmpStatisticsTracker.IncreaseResourceUsedCounter(resource, -totalCosts[resource]);
-	}
-
 	if (cmpPlayer)
 	{
 		if (this.started)
 			cmpPlayer.UnReservePopulationSlots(this.population * this.count);
+
+		const totalCosts = {};
+		for (const resource in this.resources)
+			totalCosts[resource] = Math.floor(this.count * this.resources[resource]);
+
 		cmpPlayer.RefundResources(totalCosts);
 		cmpPlayer.UnBlockTraining();
 	}
@@ -203,6 +199,14 @@ Trainer.prototype.Item.prototype.Finish = function()
 		this.finished = true;
 };
 
+/**
+ * @return {boolean} -
+ */
+Trainer.prototype.Item.prototype.IsFinished = function()
+{
+	return !!this.finished;
+};
+
 /*
  * This function creates the entities and places them in world if possible
  * (some of these entities may be garrisoned directly if autogarrison, the others are spawned).
@@ -289,7 +293,7 @@ Trainer.prototype.Item.prototype.Spawn = function()
 		createdEnts.push(ent);
 	}
 
-	if (spawnedEnts.length && !autoGarrison && cmpRallyPoint)
+	if (spawnedEnts.length && cmpRallyPoint)
 		for (const com of GetRallyPointCommands(cmpRallyPoint, spawnedEnts))
 			ProcessCommand(this.player, com);
 
@@ -550,7 +554,7 @@ Trainer.prototype.CalculateEntitiesMap = function()
 			return entMap;
 		}
 
-		token = this.GetUpgradedTemplate(token);
+		token = GetUpgradedTemplate(cmpPlayer.GetPlayerID(), token);
 		entMap.set(rawToken, token);
 		updateAllQueuedTemplate(rawToken, token);
 		return entMap;
@@ -559,32 +563,6 @@ Trainer.prototype.CalculateEntitiesMap = function()
 	this.CalculateTrainCostMultiplier();
 };
 
-/*
- * Returns the upgraded template name if necessary.
- */
-Trainer.prototype.GetUpgradedTemplate = function(templateName)
-{
-	const cmpPlayer = QueryOwnerInterface(this.entity);
-	if (!cmpPlayer)
-		return templateName;
-
-	const cmpTemplateManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_TemplateManager);
-	let template = cmpTemplateManager.GetTemplate(templateName);
-	while (template && template.Promotion !== undefined)
-	{
-		const requiredXp = ApplyValueModificationsToTemplate(
-		    "Promotion/RequiredXp",
-		    +template.Promotion.RequiredXp,
-		    cmpPlayer.GetPlayerID(),
-		    template);
-		if (requiredXp > 0)
-			break;
-		templateName = template.Promotion.Entity;
-		template = cmpTemplateManager.GetTemplate(templateName);
-	}
-	return templateName;
-};
-
 Trainer.prototype.CalculateTrainCostMultiplier = function()
 {
 	for (const res of Resources.GetCodes().concat(["time"]))
@@ -686,7 +664,7 @@ Trainer.prototype.Progress = function(id, allocatedTime)
 {
 	const item = this.queue.get(id);
 	const usedTime = item.Progress(allocatedTime);
-	if (item.finished)
+	if (item.IsFinished())
 		this.queue.delete(id);
 	return usedTime;
 };
