@@ -1,23 +1,45 @@
 Engine.LoadHelperScript("Player.js");
+Engine.LoadHelperScript("Transform.js");
+Engine.LoadHelperScript("ValueModification.js");
+Engine.LoadComponentScript("interfaces/AutoBuildable.js");
 Engine.LoadComponentScript("interfaces/Builder.js");
+Engine.LoadComponentScript("interfaces/Capturable.js");
 Engine.LoadComponentScript("interfaces/Cost.js");
 Engine.LoadComponentScript("interfaces/Foundation.js");
+Engine.LoadComponentScript("interfaces/Guard.js");
 Engine.LoadComponentScript("interfaces/Health.js");
+Engine.LoadComponentScript("interfaces/ModifiersManager.js");
+Engine.LoadComponentScript("interfaces/Population.js");
+Engine.LoadComponentScript("interfaces/Promotion.js");
+Engine.LoadComponentScript("interfaces/Repairable.js");
+Engine.LoadComponentScript("interfaces/ResourceGatherer.js");
 Engine.LoadComponentScript("interfaces/StatisticsTracker.js");
+Engine.LoadComponentScript("interfaces/StatusEffectsReceiver.js");
 Engine.LoadComponentScript("interfaces/TerritoryDecay.js");
 Engine.LoadComponentScript("interfaces/Trigger.js");
+Engine.LoadComponentScript("interfaces/Timer.js");
+Engine.LoadComponentScript("interfaces/UnitAI.js");
+Engine.LoadComponentScript("AutoBuildable.js");
 Engine.LoadComponentScript("Foundation.js");
+Engine.LoadComponentScript("Timer.js");
 
 let player = 1;
 let playerEnt = 3;
 let foundationEnt = 20;
 let previewEnt = 21;
 let newEnt = 22;
+let finalTemplate = "structures/athen/civil_centre.xml";
 
 function testFoundation(...mocks)
 {
 	ResetState();
 
+	let foundationHP = 1;
+	let maxHP = 100;
+	let rot = new Vector3D(1, 2, 3);
+	let pos = new Vector2D(4, 5);
+	let cmpFoundation;
+
 	AddMock(SYSTEM_ENTITY, IID_Trigger, {
 		"CallEvent": () => {},
 	});
@@ -40,12 +62,6 @@ function testFoundation(...mocks)
 	});
 	Engine.RegisterGlobal("MT_EntityRenamed", "entityRenamed");
 
-	let finalTemplate = "structures/athen_civil_centre.xml";
-	let foundationHP = 1;
-	let maxHP = 100;
-	let rot = new Vector3D(1, 2, 3);
-	let pos = new Vector2D(4, 5);
-
 	AddMock(foundationEnt, IID_Cost, {
 		"GetBuildTime": () => 50,
 		"GetResourceCosts": () => ({ "wood": 100 }),
@@ -76,6 +92,8 @@ function testFoundation(...mocks)
 		"GetRotation": () => rot,
 		"SetConstructionProgress": () => {},
 		"IsInWorld": () => true,
+		"GetHeightOffset": () => {},
+		"MoveOutOfWorld": () => {}
 	});
 
 	AddMock(previewEnt, IID_Ownership, {
@@ -100,6 +118,7 @@ function testFoundation(...mocks)
 	});
 
 	AddMock(newEnt, IID_Position, {
+		"GetPosition2D": () => pos,
 		"JumpTo": (x, y) => {
 			TS_ASSERT_EQUALS(x, pos.x);
 			TS_ASSERT_EQUALS(y, pos.y);
@@ -109,20 +128,22 @@ function testFoundation(...mocks)
 			TS_ASSERT_EQUALS(rx, rot.x);
 			TS_ASSERT_EQUALS(rz, rot.z);
 		},
+		"SetHeightOffset": () => {}
 	});
 
 	for (let mock of mocks)
 		AddMock(...mock);
 
 	// INITIALISE
-	Engine.AddEntity = function(template) {
+	Engine.AddLocalEntity = function(template) {
 		TS_ASSERT_EQUALS(template, "construction|" + finalTemplate);
 		return previewEnt;
 	};
-	let cmpFoundation = ConstructComponent(foundationEnt, "Foundation", {});
-	cmpFoundation.InitialiseConstruction(player, finalTemplate);
+	cmpFoundation = ConstructComponent(foundationEnt, "Foundation", {
+		"BuildTimeModifier": "0.7"
+	});
+	cmpFoundation.InitialiseConstruction(finalTemplate);
 
-	TS_ASSERT_EQUALS(cmpFoundation.owner, player);
 	TS_ASSERT_EQUALS(cmpFoundation.finalTemplateName, finalTemplate);
 	TS_ASSERT_EQUALS(cmpFoundation.maxProgress, 0);
 	TS_ASSERT_EQUALS(cmpFoundation.initialised, true);
@@ -130,8 +151,8 @@ function testFoundation(...mocks)
 	// BUILDER COUNT, BUILD RATE, TIME REMAINING
 	AddMock(10, IID_Builder, { "GetRate": () => 1.0 });
 	AddMock(11, IID_Builder, { "GetRate": () => 1.0 });
-	let twoBuilderMultiplier = Math.pow(2, cmpFoundation.buildTimePenalty) / 2;
-	let threeBuilderMultiplier = Math.pow(3, cmpFoundation.buildTimePenalty) / 3;
+	let twoBuilderMultiplier = Math.pow(2, cmpFoundation.buildTimeModifier) / 2;
+	let threeBuilderMultiplier = Math.pow(3, cmpFoundation.buildTimeModifier) / 3;
 
 	TS_ASSERT_EQUALS(cmpFoundation.CalculateBuildMultiplier(1), 1);
 	TS_ASSERT_EQUALS(cmpFoundation.CalculateBuildMultiplier(2), twoBuilderMultiplier);
@@ -208,3 +229,53 @@ testFoundation([playerEnt, IID_StatisticsTracker, {
 	},
 }]);
 
+// Test autobuild feature.
+const foundationEnt2 = 42;
+let turnLength = 0.2;
+let currentFoundationHP = 1;
+let cmpTimer = ConstructComponent(SYSTEM_ENTITY, "Timer");
+
+AddMock(foundationEnt2, IID_Cost, {
+	"GetBuildTime": () => 50,
+	"GetResourceCosts": () => ({ "wood": 100 }),
+});
+
+
+
+const cmpAutoBuildingFoundation = ConstructComponent(foundationEnt2, "Foundation", {});
+AddMock(foundationEnt2, IID_Health, {
+	"GetHitpoints": () => currentFoundationHP,
+	"GetMaxHitpoints": () => 100,
+	"Increase": hp => {
+		currentFoundationHP = Math.min(currentFoundationHP + hp, 100);
+		cmpAutoBuildingFoundation.OnHealthChanged();
+	},
+});
+
+const cmpBuildableAuto = ConstructComponent(foundationEnt2, "AutoBuildable", {
+	"Rate": "1.0"
+});
+
+cmpAutoBuildingFoundation.InitialiseConstruction(finalTemplate);
+
+// We start at 3 cause there is no delay on the first run.
+cmpTimer.OnUpdate({ "turnLength": turnLength });
+
+for (let i = 0; i < 10; ++i)
+{
+	if (i == 8)
+	{
+		cmpBuildableAuto.CancelTimer();
+		TS_ASSERT_EQUALS(cmpAutoBuildingFoundation.GetNumBuilders(), 0);
+	}
+
+	let currentPercentage = cmpAutoBuildingFoundation.GetBuildPercentage();
+	cmpTimer.OnUpdate({ "turnLength": turnLength * 5 });
+	let newPercentage = cmpAutoBuildingFoundation.GetBuildPercentage();
+
+	if (i >= 8)
+		TS_ASSERT_EQUALS(currentPercentage, newPercentage);
+	else
+		// Rate * Max Health / Cost.
+		TS_ASSERT_EQUALS(currentPercentage + 2, newPercentage);
+}
