@@ -13,12 +13,13 @@
 const showDebugLog = false;
 
 const danubiusAttackerTemplates = deepfreeze({
-	"ships": TriggerHelper.GetTemplateNamesByClasses("Warship", "gaul", undefined, undefined, true),
+	"ships": TriggerHelper.GetTemplateNamesByClasses("Trireme", "gaul", undefined, undefined, true),
 	"siege": TriggerHelper.GetTemplateNamesByClasses("Siege", "gaul", undefined, undefined, true),
 	"females": TriggerHelper.GetTemplateNamesByClasses("FemaleCitizen", "gaul", undefined, undefined, true),
 	"healers": TriggerHelper.GetTemplateNamesByClasses("Healer", "gaul", undefined, undefined, true),
 	"champions": TriggerHelper.GetTemplateNamesByClasses("Champion", "gaul", undefined, undefined, true),
 	"champion_infantry": TriggerHelper.GetTemplateNamesByClasses("Champion+Infantry", "gaul", undefined, undefined, true),
+	"infantry_ranged": TriggerHelper.GetTemplateNamesByClasses("Infantry+Ranged", "gaul", undefined, undefined, true),
 	"citizen_soldiers": TriggerHelper.GetTemplateNamesByClasses("CitizenSoldier", "gaul", undefined, "Basic", true),
 	"heroes": [
 		// Excludes the Vercingetorix variant
@@ -46,11 +47,18 @@ var gallicBuildingGarrison = [
 		"unitTemplates": danubiusAttackerTemplates.champions,
 	},
 	{
-		"buildingClasses": ["Tower", "Outpost"],
+		"buildingClasses": ["Tower"],
 		"unitTemplates": danubiusAttackerTemplates.champion_infantry
 	}
 ];
 
+var gallicBuildingTurret = [
+	{
+		"buildingClasses": ["Outpost"],
+		"unitTemplates": danubiusAttackerTemplates.infantry_ranged
+	}
+];
+
 /**
  * Notice if gaia becomes too strong, players will just turtle and try to outlast the players on the other side.
  * However we want interaction and fights between the teams.
@@ -200,6 +208,18 @@ Trigger.prototype.GarrisonAllGallicBuildings = function()
 		}
 };
 
+Trigger.prototype.TurretAllGallicBuildings = function()
+{
+	this.debugLog("Turreting all gallic buildings");
+
+	for (let buildingTurret of gallicBuildingTurret)
+		for (let buildingClass of buildingTurret.buildingClasses)
+		{
+			let unitCounts = TriggerHelper.SpawnAndTurretAtClasses(gaulPlayer, buildingClass, buildingTurret.unitTemplates, 1);
+			this.debugLog("Turreting at " + buildingClass + ": " + uneval(unitCounts));
+		}
+};
+
 /**
  * Spawn units of the template at each gaia Civic Center and set them to defensive.
  */
@@ -627,6 +647,7 @@ Trigger.prototype.InitDanubius = function()
 
 	this.StartCelticRitual();
 	this.GarrisonAllGallicBuildings();
+	this.TurretAllGallicBuildings();
 	this.SpawnInitialCCDefenders();
 	this.SpawnCCAttackers();
 
