@@ -1,6 +1,6 @@
 const debugLog = false;
 
-var attackerTemplate = "trigger/fauna_arctic_wolf_attack";
+var attackerTemplate = "gaia/fauna_wolf_arctic_violent";
 
 var minWaveSize = 1;
 var maxWaveSize = 3;
@@ -15,16 +15,15 @@ var maxWaveTime = 4;
 var targetClasses = "Organic+!Domestic";
 var targetCount = 3;
 
-var disabledTechnologies = [
-	"gather_lumbering_ironaxes",
-	"gather_lumbering_sharpaxes",
-	"gather_lumbering_strongeraxes"
-];
-
-Trigger.prototype.InitDisableTechnologies = function()
+Trigger.prototype.DisableTechnologies = function()
 {
 	for (let i = 1; i < TriggerHelper.GetNumberOfPlayers(); ++i)
-		QueryPlayerIDInterface(i).SetDisabledTechnologies(disabledTechnologies);
+		QueryPlayerIDInterface(i).SetDisabledTechnologies([
+			"gather_lumbering_ironaxes",
+			"gather_lumbering_sharpaxes",
+			"gather_lumbering_strongeraxes",
+			"gather_wicker_baskets"
+		]);
 };
 
 Trigger.prototype.SpawnWolvesAndAttack = function()
@@ -37,7 +36,6 @@ Trigger.prototype.SpawnWolvesAndAttack = function()
 
 	let allTargets;
 
-	let cmpDamage = Engine.QueryInterface(SYSTEM_ENTITY, IID_Damage);
 	let players = new Array(TriggerHelper.GetNumberOfPlayers()).fill(0).map((v, i) => i + 1);
 
 	for (let spawnPoint in attackers)
@@ -52,7 +50,8 @@ Trigger.prototype.SpawnWolvesAndAttack = function()
 			continue;
 
 		// The returned entities are sorted by RangeManager already
-		let targets = cmpDamage.EntitiesNearPoint(attackerPos, 200, players).filter(ent => {
+		// Only consider units implementing Health since wolves deal damage.
+		let targets = PositionHelper.EntitiesNearPoint(attackerPos, 200, players, IID_Health).filter(ent => {
 			let cmpIdentity = Engine.QueryInterface(ent, IID_Identity);
 			return cmpIdentity && MatchesClassList(cmpIdentity.GetClassesList(), targetClasses);
 		});
@@ -108,6 +107,6 @@ Trigger.prototype.SpawnWolvesAndAttack = function()
 
 {
 	let cmpTrigger = Engine.QueryInterface(SYSTEM_ENTITY, IID_Trigger);
-	cmpTrigger.InitDisableTechnologies();
+	cmpTrigger.RegisterTrigger("OnInitGame", "DisableTechnologies", { "enabled": true });
 	cmpTrigger.DoAfterDelay(firstWaveTime * 60 * 1000, "SpawnWolvesAndAttack", {});
 }
