@@ -4,6 +4,6 @@ function setupBiome_savanna()
 		"gaia/fauna_wildebeest",
 		"gaia/fauna_zebra",
 		"gaia/fauna_giraffe",
-		"gaia/fauna_elephant_african_bush"
+		"gaia/fauna_gazelle"
 	]);
 }
