@@ -11,13 +11,11 @@ class PhaseIdentManager
 			this.Idents.push(new PhaseIdent(this.page, identIdx));
 	}
 
-	draw(phaseList, civCode, runningWidths, leftMargin)
+	draw(phaseList, civCode)
 	{
 		for (let i = 0; i < phaseList.length; ++i)
-		{
-			let barLength = leftMargin + runningWidths[i] + EntityBox.prototype.HMargin * 0.75;
-			this.Idents[i].draw(phaseList, barLength, civCode);
-		}
+			this.Idents[i].draw(phaseList, civCode);
+
 		hideRemaining(this.PhaseIdents.name, phaseList.length);
 	}
 }
