@@ -95,6 +95,21 @@ TriggerHelper.SetUnitFormation = function(playerID, entities, formation)
 	});
 };
 
+/**
+ * Creates a new unit taking into account possible 0 experience promotion.
+ * @param {number} owner Player id of the owner of the new units.
+ * @param {string} template Name of the template.
+ * @returns the created entity id.
+ */
+TriggerHelper.AddUpgradeTemplate = function(owner, template)
+{
+	const upgradedTemplate = GetUpgradedTemplate(owner, template);
+	if (upgradedTemplate !== template)
+		warn(`tried to spawn template '${template}' but upgraded template '${upgradedTemplate}' will be spawned instead. You might want to create a template that is not affected by this promotion.`);
+
+	return Engine.AddEntity(upgradedTemplate);
+};
+
 /**
  * Can be used to "force" a building/unit to spawn a group of entities.
  *
@@ -121,7 +136,8 @@ TriggerHelper.SpawnUnits = function(source, template, count, owner)
 
 	for (let i = 0; i < count; ++i)
 	{
-		let ent = Engine.AddEntity(template);
+		const ent = this.AddUpgradeTemplate(owner, template);
+
 		let cmpEntPosition = Engine.QueryInterface(ent, IID_Position);
 		if (!cmpEntPosition)
 		{
@@ -178,7 +194,7 @@ TriggerHelper.SpawnGarrisonedUnits = function(entity, template, count, owner)
 
 	for (let i = 0; i < count; ++i)
 	{
-		let ent = Engine.AddEntity(template);
+		const ent = this.AddUpgradeTemplate(owner, template);
 
 		let cmpOwnership = Engine.QueryInterface(ent, IID_Ownership);
 		if (cmpOwnership)
@@ -219,7 +235,7 @@ TriggerHelper.SpawnTurretedUnits = function(entity, template, count, owner)
 
 	for (let i = 0; i < count; ++i)
 	{
-		let ent = Engine.AddEntity(template);
+		const ent = this.AddUpgradeTemplate(owner, template);
 
 		let cmpOwnership = Engine.QueryInterface(ent, IID_Ownership);
 		if (cmpOwnership)
@@ -540,14 +556,14 @@ TriggerHelper.SpawnAndGarrisonAtClasses = function(playerID, classes, templates,
 
 	for (let entGarrisonHolder of Engine.QueryInterface(SYSTEM_ENTITY, IID_RangeManager).GetEntitiesByPlayer(playerID))
 	{
-		let cmpIdentity = Engine.QueryInterface(entGarrisonHolder, IID_Identity);
-		if (!cmpIdentity || !MatchesClassList(cmpIdentity.GetClassesList(), classes))
-			continue;
-
 		let cmpGarrisonHolder = Engine.QueryInterface(entGarrisonHolder, IID_GarrisonHolder);
 		if (!cmpGarrisonHolder)
 			continue;
 
+		let cmpIdentity = Engine.QueryInterface(entGarrisonHolder, IID_Identity);
+		if (!cmpIdentity || !MatchesClassList(cmpIdentity.GetClassesList(), classes))
+			continue;
+
 		// TODO: account for already garrisoned entities and garrison size.
 		results[entGarrisonHolder] = this.RandomTemplateComposition(templates, Math.floor(cmpGarrisonHolder.GetCapacity() * capacityPercent));
 
