@@ -101,9 +101,13 @@ function updateCursorAndTooltip()
 	let cursorSet = false;
 	let tooltipSet = false;
 	let informationTooltip = Engine.GetGUIObjectByName("informationTooltip");
-	if (inputState == INPUT_FLARE || inputState == INPUT_NORMAL && Engine.HotkeyIsPressed("session.flare") && !g_IsObserver)
+	if (!g_IsReplay && (inputState == INPUT_FLARE || (inputState == INPUT_NORMAL && Engine.HotkeyIsPressed("session.flare"))))
 	{
-		Engine.SetCursor("action-flare");
+		Engine.SetCursor(
+			g_IsObserver ?
+				"action-observer-flare" :
+				"action-player-flare"
+		);
 		cursorSet = true;
 	}
 	else if (!mouseIsOverObject && (inputState == INPUT_NORMAL || inputState == INPUT_PRESELECTEDACTION) || g_MiniMapPanel.isMouseOverMiniMap())
@@ -825,7 +829,7 @@ function handleInputAfterGui(ev)
 			return false;
 
 		case "mousebuttondown":
-			if (Engine.HotkeyIsPressed("session.flare") && controlsPlayer(g_ViewedPlayer))
+			if (Engine.HotkeyIsPressed("session.flare") && !g_IsReplay)
 			{
 				triggerFlareAction(Engine.GetTerrainAtScreenPoint(ev.x, ev.y));
 				return true;
@@ -1134,7 +1138,7 @@ function handleInputAfterGui(ev)
 	case INPUT_FLARE:
 		if (ev.type == "mousebuttondown")
 		{
-			if (ev.button == SDL_BUTTON_LEFT && controlsPlayer(g_ViewedPlayer))
+			if (ev.button == SDL_BUTTON_LEFT)
 			{
 				triggerFlareAction(Engine.GetTerrainAtScreenPoint(ev.x, ev.y));
 				inputState = INPUT_NORMAL;
@@ -1259,22 +1263,20 @@ function positionUnitsFreehandSelectionMouseUp(ev)
 	return true;
 }
 
-function triggerFlareAction(target)
+function triggerFlareAction(position)
 {
-		let now = Date.now();
-		if (g_LastFlareTime && now < g_LastFlareTime + g_FlareCooldown)
-			return;
+	let now = Date.now();
+	if (g_LastFlareTime && now < g_LastFlareTime + g_FlareCooldown)
+		return;
 
-		g_LastFlareTime = now;
-		displayFlare(target, Engine.GetPlayerID());
-		Engine.PlayUISound(g_FlareSound, false);
-		Engine.PostNetworkCommand({
-			"type": "map-flare",
-			"target": target
-		});
+	g_LastFlareTime = now;
+
+	renderAndPlayFlare(position, Engine.GetPlayerGUID());
+	if (Engine.HasNetClient())
+		Engine.SendNetworkFlare(position);
 }
 
-function handleUnitAction(target, action)
+function handleUnitAction(position, action)
 {
 	if (!g_UnitActions[action.type] || !g_UnitActions[action.type].execute)
 	{
@@ -1288,7 +1290,7 @@ function handleUnitAction(target, action)
 	// of running it immediately. If the pushorderfront hotkey is down, execute the order
 	// immidiately and continue the rest of the queue afterwards.
 	return g_UnitActions[action.type].execute(
-		target,
+		position,
 		action,
 		selection,
 		Engine.HotkeyIsPressed("session.queue"),
