@@ -186,7 +186,7 @@ function displaySingle(entState)
 
 		let showSmallCapture = showResource && showHealth;
 		Engine.GetGUIObjectByName("captureStats").caption = showSmallCapture ? "" : captureText;
-		Engine.GetGUIObjectByName("capture").tooltip = showSmallCapture ? captureText : "";
+		Engine.GetGUIObjectByName("captureTooltip").tooltip = showSmallCapture ? getCurrentCaptureTooltip(entState) : translate("Capture Points");
 	}
 
 	// Experience
@@ -317,16 +317,46 @@ function displaySingle(entState)
 		});
 	secondaryObject.hidden = hideSecondary;
 
-	let isGaia = playerState.civ == "gaia";
+	const isGaia = playerState.civ == "gaia";
 	Engine.GetGUIObjectByName("playerCivIcon").sprite = isGaia ? "" : "cropped:1.0, 0.15625 center:grayscale:" + civEmblem;
-	Engine.GetGUIObjectByName("player").tooltip = isGaia ? "" : civName;
+
+	if (isGaia)
+	{
+		Engine.GetGUIObjectByName("phaseEmblems").sprite = "";
+		Engine.GetGUIObjectByName("civilizationTooltip").tooltip = "";
+	}
+	else
+	{
+		let civilizationTooltip = civName;
+		let civPhaseEmblems = "session/panel_phase_emblems_hidden.png";
+
+		// Reveal phases to mutual allies and observers
+		if (g_ViewedPlayer == -1 || playerState.isMutualAlly[g_ViewedPlayer])
+		{
+			const civPhase = g_SimState.players[entState.player].phase
+			civPhaseEmblems = "session/panel_phase_emblems_" + civPhase + ".png";
+			const civPhaseData = GetTechnologyData("phase_" + civPhase + "_" + playerState.civ, playerState.civ) ||
+				GetTechnologyData("phase_" + civPhase, playerState.civ);
+			civilizationTooltip += " — " + getEntityNames(civPhaseData);
+		}
+		Engine.GetGUIObjectByName("phaseEmblems").sprite = "cropped:1.0, 1.0 center:" + civPhaseEmblems;
+		Engine.GetGUIObjectByName("civilizationTooltip").tooltip = civilizationTooltip;
+	}
 
 	// TODO: we should require all entities to have icons
 	Engine.GetGUIObjectByName("icon").sprite = template.icon ? ("stretched:session/portraits/" + template.icon) : "BackgroundBlack";
 	if (template.icon)
-		Engine.GetGUIObjectByName("iconBorder").onPressRight = () => {
+	{
+		const iconBorder = Engine.GetGUIObjectByName("iconBorder");
+
+		iconBorder.onPress = () => {
+			setCameraFollow(entState.id);
+		};
+
+		iconBorder.onPressRight = () => {
 			showTemplateDetails(entState.template, playerState.civ);
 		};
+	}
 
 	let detailedTooltip = [
 		getAttackTooltip,
@@ -357,10 +387,12 @@ function displaySingle(entState)
 		getVisibleEntityClassesFormatted,
 		getAurasTooltip,
 		getEntityTooltip,
-		getTreasureTooltip,
-		showTemplateViewerOnRightClickTooltip
+		getTreasureTooltip
 	].map(func => func(template)));
 
+	const leftClickTooltip = hasClass(entState, "Unit") ? getFollowOnLeftClickTooltip() : getFocusOnLeftClickTooltip();
+	iconTooltips.push(leftClickTooltip + " " + getTemplateViewerOnRightClickTooltip());
+
 	Engine.GetGUIObjectByName("iconBorder").tooltip = iconTooltips.filter(tip => tip).join("\n");
 
 	Engine.GetGUIObjectByName("detailsAreaSingle").hidden = false;
