@@ -63,10 +63,22 @@ g_SelectionPanels.Alert = {
 		case "raise":
 			data.icon.sprite = "stretched:session/icons/bell_level1.png";
 			data.button.tooltip = translate("Raise an alert!");
+			if (data.unitEntStates.every(state => MatchesClassList(["FemaleCitizen"], state.alertRaiser?.classes)))
+				data.button.tooltip += "\n" + bodyFont(translate("Alert nearby Female Citizens to seek refuge."));
+			else if (data.unitEntStates.every(state => MatchesClassList(["Trader"], state.alertRaiser?.classes)))
+				data.button.tooltip += "\n" + bodyFont(translate("Alert nearby Traders to seek refuge."));
+			else
+				data.button.tooltip += "\n" + bodyFont(translate("Alert nearby vulnerable units to seek refuge."));
 			break;
 		case "end":
-			data.button.tooltip = translate("End of alert.");
 			data.icon.sprite = "stretched:session/icons/bell_level0.png";
+			data.button.tooltip = translate("End the alert.");
+			if (data.unitEntStates.every(state => MatchesClassList(["FemaleCitizen"], state.alertRaiser?.classes)))
+				data.button.tooltip += "\n" + bodyFont(translate("Unload nearby Female Citizens."));
+			else if (data.unitEntStates.every(state => MatchesClassList(["Trader"], state.alertRaiser?.classes)))
+				data.button.tooltip += "\n" + bodyFont(translate("Unload nearby Traders."));
+			else
+				data.button.tooltip += "\n" + bodyFont(translate("Unload nearby vulnerable units."));
 			break;
 		}
 		data.button.enabled = controlsPlayer(data.player);
@@ -166,8 +178,8 @@ g_SelectionPanels.Construction = {
 		if (!template)
 			return false;
 
-		let technologyEnabled = Engine.GuiInterfaceCall("IsTechnologyResearched", {
-			"tech": template.requiredTechnology,
+		const requirementsMet = Engine.GuiInterfaceCall("AreRequirementsMet", {
+			"requirements": template.requirements,
 			"player": data.player
 		});
 
@@ -195,7 +207,7 @@ g_SelectionPanels.Construction = {
 			getGarrisonTooltip(template),
 			getTurretsTooltip(template),
 			getPopulationBonusTooltip(template),
-			showTemplateViewerOnRightClickTooltip(template)
+			getTemplateViewerOnRightClickTooltip(template)
 		);
 
 
@@ -203,13 +215,13 @@ g_SelectionPanels.Construction = {
 		tooltips.push(
 			formatLimitString(limits.entLimit, limits.entCount, limits.entLimitChangers),
 			formatMatchLimitString(limits.matchLimit, limits.matchCount, limits.type),
-			getRequiredTechnologyTooltip(technologyEnabled, template.requiredTechnology, GetSimState().players[data.player].civ),
+			getRequirementsTooltip(requirementsMet, template.requirements, GetSimState().players[data.player].civ),
 			getNeededResourcesTooltip(neededResources));
 
 		data.button.tooltip = tooltips.filter(tip => tip).join("\n");
 
 		let modifier = "";
-		if (!technologyEnabled || limits.canBeAddedCount == 0)
+		if (!requirementsMet || limits.canBeAddedCount == 0)
 		{
 			data.button.enabled = false;
 			modifier += "color:0 0 0 127:grayscale:";
@@ -270,6 +282,8 @@ g_SelectionPanels.Formation = {
 
 		let formationInfo = g_FormationsInfo.get(data.item);
 		let tooltip = translate(formationInfo.name);
+		if (formationInfo.tooltip)
+			tooltip += "\n" + bodyFont(translate(formationInfo.tooltip));
 
 		let isDefaultFormation = g_AutoFormation.isDefault(data.item);
 		if (data.item === NULL_FORMATION)
@@ -281,8 +295,8 @@ g_SelectionPanels.Formation = {
 				translate("This is the default formation, used for movement orders.") :
 				translate("Right-click to set this as the default formation."));
 
-		if (!formationOk && formationInfo.tooltip)
-			tooltip += "\n" + coloredText(translate(formationInfo.tooltip), "red");
+		if (!formationOk && formationInfo.disabledTooltip)
+			tooltip += "\n" + objectionFont(translate(formationInfo.disabledTooltip));
 		data.button.tooltip = tooltip;
 
 		data.button.enabled = formationOk && controlsPlayer(data.player);
@@ -328,7 +342,7 @@ g_SelectionPanels.Garrison = {
 			unloadTemplate(template.selectionGroupName || entState.template, entState.player);
 		};
 
-		data.countDisplay.caption = data.item.ents.length || "";
+		data.countDisplay.caption = data.item.ents.length > 1 ? data.item.ents.length : "";
 
 		let canUngarrison = controlsPlayer(data.player) || controlsPlayer(entState.player);
 
@@ -558,13 +572,13 @@ g_SelectionPanels.Queue = {
 			tooltips.push(translate("The auto-queue will try to train this item later."));
 		if (queuedItem.neededSlots)
 		{
-			tooltips.push(coloredText(translate("Insufficient population capacity:"), "red"));
+			tooltips.push(objectionFont(translate("Insufficient population capacity:")));
 			tooltips.push(sprintf(translate("%(population)s %(neededSlots)s"), {
 				"population": resourceIcon("population"),
 				"neededSlots": queuedItem.neededSlots
 			}));
 		}
-		tooltips.push(showTemplateViewerOnRightClickTooltip(template));
+		tooltips.push(getTemplateViewerOnRightClickTooltip(template));
 		data.button.tooltip = tooltips.join("\n");
 
 		data.countDisplay.caption = queuedItem.count > 1 ? queuedItem.count : "";
@@ -749,7 +763,7 @@ g_SelectionPanels.Research = {
 				getEntityNamesFormatted,
 				getEntityTooltip,
 				getEntityCostTooltip,
-				showTemplateViewerOnRightClickTooltip
+				getTemplateViewerOnRightClickTooltip
 			].map(func => func(template));
 
 			if (!requirementsPassed)
@@ -791,7 +805,7 @@ g_SelectionPanels.Research = {
 						"entityCounts": entityCounts.join(translateWithContext("Separator for a list of entity counts", ", "))
 					});
 				}
-				tooltips.push(tip);
+				tooltips.push(objectionFont(tip));
 			}
 			tooltips.push(getNeededResourcesTooltip(neededResources));
 			button.tooltip = tooltips.filter(tip => tip).join("\n");
@@ -840,7 +854,7 @@ g_SelectionPanels.Research = {
 			{
 				button.enabled = false;
 				modifier += "color:0 0 0 127:grayscale:";
-				button.tooltip += "\n" + coloredText(translate("Cannot research while upgrading."), "red");
+				button.tooltip += "\n" + objectionFont(translate("Cannot research while upgrading."));
 
 			}
 
@@ -924,7 +938,7 @@ g_SelectionPanels.Selection = {
 		data.guiSelection.sprite = "color:" + g_DiplomacyColors.getPlayerColor(unitOwner, 160);
 		data.guiSelection.hidden = !g_IsObserver;
 
-		data.countDisplay.caption = data.item.ents.length || "";
+		data.countDisplay.caption = data.item.ents.length > 1 ? data.item.ents.length : "";
 
 		data.button.onPress = function() {
 			if (Engine.HotkeyIsPressed("session.deselectgroup"))
@@ -959,8 +973,7 @@ g_SelectionPanels.Stance = {
 		let unitIds = data.unitEntStates.map(state => state.id);
 		data.button.onPress = function() { performStance(unitIds, data.item); };
 
-		data.button.tooltip = getStanceDisplayName(data.item) + "\n" +
-			"[font=\"sans-13\"]" + getStanceTooltip(data.item) + "[/font]";
+		data.button.tooltip = getStanceDisplayName(data.item) + "\n" + bodyFont(getStanceTooltip(data.item));
 
 		data.guiSelection.hidden = !Engine.GuiInterfaceCall("IsStanceSelected", {
 			"ents": unitIds,
@@ -990,8 +1003,8 @@ g_SelectionPanels.Training = {
 		if (!template)
 			return false;
 
-		let technologyEnabled = Engine.GuiInterfaceCall("IsTechnologyResearched", {
-			"tech": template.requiredTechnology,
+		const requirementsMet = Engine.GuiInterfaceCall("AreRequirementsMet", {
+			"requirements": template.requirements,
 			"player": data.player
 		});
 
@@ -1045,16 +1058,16 @@ g_SelectionPanels.Training = {
 				getResourceDropsiteTooltip
 			].map(func => func(template)));
 
-		tooltips.push(showTemplateViewerOnRightClickTooltip());
+		tooltips.push(getTemplateViewerOnRightClickTooltip());
 		tooltips.push(
 			formatBatchTrainingString(buildingsCountToTrainFullBatch, fullBatchSize, remainderBatch),
-			getRequiredTechnologyTooltip(technologyEnabled, template.requiredTechnology, GetSimState().players[data.player].civ),
+			getRequirementsTooltip(requirementsMet, template.requirements, GetSimState().players[data.player].civ),
 			getNeededResourcesTooltip(neededResources));
 
 		data.button.tooltip = tooltips.filter(tip => tip).join("\n");
 
 		let modifier = "";
-		if (!technologyEnabled || limits.canBeAddedCount == 0)
+		if (!requirementsMet || limits.canBeAddedCount == 0)
 		{
 			data.button.enabled = false;
 			modifier = "color:0 0 0 127:grayscale:";
@@ -1070,7 +1083,7 @@ g_SelectionPanels.Training = {
 		{
 			data.button.enabled = false;
 			modifier = "color:0 0 0 127:grayscale:";
-			data.button.tooltip += "\n" + coloredText(translate("Cannot train while upgrading."), "red");
+			data.button.tooltip += "\n" + objectionFont(translate("Cannot train while upgrading."));
 		}
 
 		if (template.icon)
@@ -1106,11 +1119,9 @@ g_SelectionPanels.Upgrade = {
 		let progressOverlay = Engine.GetGUIObjectByName("unitUpgradeProgressSlider[" + data.i + "]");
 		progressOverlay.hidden = true;
 
-		let technologyEnabled = true;
-
-		if (data.item.requiredTechnology)
-			technologyEnabled = Engine.GuiInterfaceCall("IsTechnologyResearched", {
-				"tech": data.item.requiredTechnology,
+		const requirementsMet = !data.item.requirements ||
+			Engine.GuiInterfaceCall("AreRequirementsMet", {
+				"requirements": data.item.requirements,
 				"player": data.player
 			});
 
@@ -1167,9 +1178,10 @@ g_SelectionPanels.Upgrade = {
 				getEntityCostTooltip(data.item, undefined, undefined, data.unitEntStates.length),
 				formatLimitString(limits.entLimit, limits.entCount, limits.entLimitChangers),
 				formatMatchLimitString(limits.matchLimit, limits.matchCount, limits.type),
-				getRequiredTechnologyTooltip(technologyEnabled, data.item.requiredTechnology, GetSimState().players[data.player].civ),
+				getRequirementsTooltip(requirementsMet, data.item.requirements, GetSimState().players[data.player].civ),
 				getNeededResourcesTooltip(neededResources),
-				showTemplateViewerOnRightClickTooltip());
+				getTemplateViewerOnRightClickTooltip()
+			);
 
 			tooltip = tooltips.filter(tip => tip).join("\n");
 
@@ -1179,7 +1191,7 @@ g_SelectionPanels.Upgrade = {
 				    upgradableEntStates.map(state => state.id));
 			};
 
-			if (!technologyEnabled || limits.canBeAddedCount == 0 &&
+			if (!requirementsMet || limits.canBeAddedCount == 0 &&
 				!upgradableEntStates.some(state => hasSameRestrictionCategory(data.item.entity, state.template)))
 			{
 				data.button.enabled = false;
@@ -1210,10 +1222,10 @@ g_SelectionPanels.Upgrade = {
 		}
 		else
 		{
-			tooltip = coloredText(translatePlural(
+			tooltip = objectionFont(translatePlural(
 				"Cannot upgrade when the entity is training, researching or already upgrading.",
 				"Cannot upgrade when all entities are training, researching or already upgrading.",
-				data.unitEntStates.length), "red");
+				data.unitEntStates.length));
 
 			data.button.onPress = function() {};
 
@@ -1251,19 +1263,19 @@ function initSelectionPanels()
  *
  * @param {string} [civCode] - The template name of the entity that researches the selected technology.
  */
-function showTemplateDetails(templateName, civCode)
+async function showTemplateDetails(templateName, civCode)
 {
 	if (inputState != INPUT_NORMAL)
 		return;
 	g_PauseControl.implicitPause();
 
-	Engine.PushGuiPage(
+	await Engine.PushGuiPage(
 		"page_viewer.xml",
 		{
 			"templateName": templateName,
 			"civ": civCode
-		},
-		resumeGame);
+		});
+	resumeGame();
 }
 
 /**
